bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 23. Aventiure
___________________________________________________ #### Aventivre wie krimhilt ir leit #### gedaht ze rechen
###### 1387 | ### Mit vil grozen eren | daz ist alwar ### wonten si mit einander | vnz an daz sibende iar ### di zit div chveneginne | eines svns was genesen ### des chvnde der kvenich ecel | nimmer vroelicher wesen
###### 1388 | ### si ne wolde niht erwinden | sine wuerbe sint ### daz getovffet wuerde | daz eceln chint ### nach cristenlichem rehte | ez wart ortliep genant ### des wart vil michel vrevde | vber elliv eceln lant
###### 1389 | ### swaz ie gvter tvgende | an vrovn helchen lach ### der vleiz sich nv vrov criemhilt | darnach vil manigen tach ### di site si lerte herrat | div ellende meit ### div hete tovgenliche | nach helchen groziv leit
###### 1390 | ### den vremden vnt den chvnden | was si vil wol bechant ### di iahen daz nie vrowe | besaeze ein kveneges lant ### bezzer vnde milter | daz heten si fver war ### daz lop si trvch si cen hivnen | vnz an daz dricehende iar
###### 1391 | ### nv het si wol erchvnnen | daz ir niemen widerstvnt ### also noch fvrsten wibe | chveneges recken tvnt ### vnt daz si alle zite | zwelf chvenige vor ir sach ### si gedaht ovch maniger leide | der ir da heime gesach
###### 1392 | ### si gedaht ovch maniger eren | von nibelvnge lant ### der si da was gewaltich | vnt di ir hagenen hant ### mit sifrides tode | hete gar benomen ### ob im daz noch immer von ir | ce leide mohte chomen
###### 1393 | ### daz geschaehe ob ich in | moehte bringen in daz lant ### ir trovmte daz ir gienge | vil diche an der hant ### giselher ir brvder | si chvsten zaller stvnt ### vil ofte in senftem slaffe | sit wart in arbeiten chvnt
###### 1394 | ### ich waene der vbel valant | criemhilde daz geriet ### daz si sich mit frivntschefte | von giselhere schiet ### den si dvrch svne chvste | in bvergonden lant ### do begonde ir aber salwen | von heizen trehen ir gewant
###### 1395 | ### ez lag ir an dem hercen | spate vnd vrov ### wi man si ane schvlde | braehte darzv ### daz si mvese minnen | einen heidenisschen man ### di not di het ir hagene | vnt gvnther getan
###### 1396 | ### des willen in ir hercen | chom si vil selten abe ### si gedahte ich pin so riche | vnt han so groze habe ### daz ich minen vinden | gefvege noch ein leit ### des waere et ich von tronege | hagen gerne bereit
###### 1397 | ### nach den getriwen iamert | diche daz herce min ### di mir da leide taten | moehte ich pi den sin ### so wuerde wol errochen | mines vrivndes lip ### des ich chvme erbeite | sprach daz ecelen wip
###### 1398 | ### ze liebe si do heten | alle skveneges man ### di criemhilde recken | daz was vil wol getan ### der chamern der pflach eckewart | davon er frivnt gewan ### den crimhilde willen | chvnde niemen vnderstan
###### 1399 | ### si dahte zallen ziten | ich wil den chvenech piten ### daz er ir des gonde | mit gvetlichen siten ### daz man ir frivnde braehte | in der hivnen lant ### den argen willen niemen | an der chvneginn ervant
###### 1400 | ### do si eines nahtes | bi dem chvenige lach ### mit armen vmbvangen | het er si als er pflach ### di edeln vrowen trivten | si was im also sin lip ### do gedahte ir finde | daz vil herliche wip
###### 1401 | ### si sprach zv dem chvenige | vil lieber herre min ### ich wolde ivch bitten gerne | moht iz mit hvlden sin ### daz ir mich liezet sehen | ob ich daz het versolt ### ob ir den minen vrivnden | waeret innechlichen holt
###### 1402 | ### do sprach der kvenich riche | getriwe was sin mvt ### ich bringe ivch des wol innen | swa lip vnd gvt ### den recken widerfvere | des mvese ich frevde han ### wande ich von wibes minne | nie bezer frivnde gewan
###### 1403 | ### do sprach div chveneginne | iv ist daz wol geseit ### ich han vil hoher mage | darvmbe ist mir so leit ### daz mich di so selten | rvchent hie gesehen ### ich hoere min div livte | niwan fver ellende iehen
###### 1404 | ### do sprach der chvenech ecel | vil liebiv vrowe min ### divht ez si niht ce verre | so lvede ich veber rin ### swelhe ir da gerne saehet | her in miniv lant ### des vrevote sich div vrowe | do si den willen sin ervant
###### 1405 | ### si sprach welt ir mir triwe | leisten herre min ### so svlt ir boten senden | ce wormez veber rin ### so enbivt ich minen vrivnden | des ich da habe mvt ### so chvmt vns her ce lande | vil manich edel ritter gvt
###### 1406 | ### er sprach swenne ir gebietet | so lazet ez geschehen ### irn chvndet iwer vrivnde | so gerne niht gesehen ### als ich si gesaehe | der edeln vten chint ### mich muewet daz harte sere | daz si vns so lange vremde sint
###### 1407 | ### ob ez dir wol gevalle | vil liebiv vrowe min ### so wold ich gerne senden | nach den frivnden din ### di minen videlaere | in bvergonden lant ### di gvten videlaere | hiez er bringen sa cehant
###### 1408 | ### si ilten harte balde | da der kvenech saz ### bi der chveneginne | er saget in beiden daz ### si solden poten werden | in bvergonden lant ### do hiez er in bereiten | harte herlich gewant
###### 1409 | ### vier vnd zweinzech recken | bereite man div chleit ### ovch wart in von dem chvenege | div boteschaft geseit ### wi si dar laden solden | gventher vnd sine man ### criemhilt div vrowe | si svnder sprechen began
###### 1410 | ### do sprach der kvenech riche | ich sage iv wi ir tvt ### ich enbivte minen vrivnden | liep vnde allez gvt ### daz si gervchen ritten | her in miniv lant ### ich han so lieber geste | harte wenich noch bechant
###### 1411 | ### vnde ob si mines willen | wellen iht began ### di criemhilde mage | daz si des niht en lan ### si ne chomen an disem svmere | zv miner hohgecit ### wand vil der minen wuenne | an minen chonemagen lit
###### 1412 | ### do sprach der videlaere | der stolze swemmelin ### wenne sol iwer hohzit | in disen landen sin ### daz wir daz ivren frivnden | chvnnen dort gesagen ### do sprach der kvenech ecel | ce naehsten svnewenden tagen
###### 1413 | ### wir tvn swaz ir gebietet | sprach do waerbelin ### in ir chemnaten | bat si div chvenegin ### bringen tovgenliche | da si di boten sprach ### davon vil manigem degene | sit wenich liebes gesach
###### 1414 | ### si sprach cen boten beiden | nv dienet michel gvt ### daz ir minen willen | vil gvetlichen tvt ### vnd saget swaz ich enbiete | heim in vnser lant ### ich mache ivch gvtes riche | vnt gip iv herlich gewant
###### 1415 | ### vnde swaz ir miner frivnde | immer mvget gesehen ### ze wormez bi dem rine | den svlt ir niht veriehen ### daz ir noch nie gesaehet | betrvebet minen mvt ### vnt saget minen dienest | den helden chvene vnde gvt
###### 1416 | ### bittet daz si lesten | daz in rvedger enbot ### vnt mich damite scheiden | von aller miner not ### di hivnen wellent waenen | deich ane vrivnde si ### ob ich ein ritter waere | ich chom in etwenne bi
###### 1417 | ### vnde sagt ovch gernot | dem edelen brvder min ### daz im zer werlde holder | niemen mvege sin ### bittet daz er mir bringe | in diz lant ### vnser besten frivnde | derz vns cen eren si gewant
###### 1418 | ### so sagt ovch giselher | daz er wol gedenche daran ### daz ich von sinen schvlden | nie leides niht gewan ### des saehen in vil gerne | hie div ovgen min ### ich heten in hie vil gerne | dvrch di grozen triwe sin
###### 1419 | ### sagt ovch miner mvter | di ere di ich han ### vnd ob von tronege hagene | welle dort bestan ### wer si danne sold | wisen dvrch div lant ### dem sint di wege von chinde | her cen hivnen wol bechant
###### 1420 | ### di boten nine westen | wavon daz was getan ### daz si von tronege hagen | niht solden lan ### beliben bi dem rine | ez wart in sider leit ### mit im was manigem degene | ze grimmem tode widerseit
###### 1421 | ### brieve vnde botschaft | was in nv gegeben ### si fvren gvtes riche | vnd mohten schone leben ### vrlovb gap in ecel | vnd ovch sin schoene wip ### in was von gvter waete | wol gezieret der lip

<<< Übersicht <<< vorige Seite nächste Seite >>>